/*******************************************************************************
 *	Dtest1.c	CHASE_DA Linux Device Driver Test
 *			T.Barnaby,	BEAM Ltd,	2007-01-09
 *******************************************************************************
 * Copyright (c) 2009 BEAM Ltd. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#include <stdio.h>
#include <fcntl.h>
#include <errno.h>
#include <stdint.h>
#include <sys/ioctl.h>
#include <sys/mman.h>
#include "chase_da.h"

int main(){
	int			fd;
	ChaseDaInfo		info;
	int			r;
	volatile uint16_t*	mem;
	
	if((fd = open("/dev/chase_da-0", O_RDWR)) < 0){
		fprintf(stderr, "Error opening device: %s\n", strerror(errno));
		return 1;
	}

	printf("Board Opened\n");

#ifndef ZAP	
	if((r = ioctl(fd, CHASE_DA_CMD_GETINFO, &info)) < 0){
		fprintf(stderr, "Error ioctl: %s\n", strerror(errno));
		return 1;
	}
	printf("BoradType: %d\n", info.boardType);
	printf("Addresses: %x(%x) %x(%x)\n", info.regsPhysAddress, info.regsLen, info.memPhysAddress, info.memLen);

	if((mem = mmap(0, info.memLen, PROT_READ|PROT_WRITE, MAP_SHARED, fd, info.memPhysAddress)) == 0){
		fprintf(stderr, "Error mmap: %s\n", strerror(errno));
		return 1;
	}
	
	printf("Memory Mapped at: %p\n", mem);
	printf("MemoryValue: %x\n", mem[0]);
	mem[0] = 0x1122;
	printf("MemoryValue: %x\n", mem[0]);
#endif
	
	close(fd);
	return 0;
}
