/*******************************************************************************
 *	Test3.c			CHASE_DA test code
 *				T.Barnaby,	BEAM Ltd,	2009-05-08
 *******************************************************************************
 *
 * This program generates a sine wave for 2 * 1024 samples followed by
 * a DC level of 2047 for 1024 samples.
 * On a DA8150 the waveform frequency is: 146KHz (150/1024).
 * On a DA11000 the waveform frequency is: 976KHz (1G/1024).
 *
 * Copyright (c) 2009 BEAM Ltd. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */
#include <stdio.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdint.h>
#include <errno.h>
#include <math.h>
#include <chase_da_lib.h>

int main(){
	int		i;
	int		cardNum = 1;
	int		nPoints = 1*1024;
	int		r;
	ChaseDaSegment	segs[2];
	uint16_t	data0[nPoints];
	uint16_t	data1[nPoints];
	
	i = chase_da_CountCards();
	printf("There are %d CHASE_DA cards in the system\n", i);

	printf("Open Card\n");
	if(r = chase_da_Open(cardNum)){
		fprintf(stderr, "Error unable to open CHASE_DA: %d\n", r);
		return 1;
	}

	chase_da_SetClock(cardNum, 150000000);
	chase_da_CleanSingleSegmentArea(cardNum, nPoints);
	
	// Create Segment #1
	for(i = 0; i < nPoints; i++){
		data0[i] = (uint16_t)ceil(2047.0 - 2047 * sin(2 * M_PI * i/nPoints));
//		data1[i] = (uint16_t)ceil(2047.0 - 2047 * sin(2 * M_PI * i/(nPoints/2)));
		data1[i] = 2047;
	}

	segs[0].segmentNum = 0;
	segs[0].data = data0;
	segs[0].numPoints = nPoints;
	segs[0].numLoops = 0;
	segs[0].beginPadValue = 2047;
	segs[0].endPadValue = 2047;
	segs[0].trigEnable = 0;
	segs[0].nextSegNum = 1;

	segs[1].segmentNum = 1;
	segs[1].data = data1;
	segs[1].numPoints = nPoints;
	segs[1].numLoops = 1;
	segs[1].beginPadValue = 2047;
	segs[1].endPadValue = 2047;
	segs[1].trigEnable = 0;
	segs[1].nextSegNum = 0;

	printf("Create Segments\n");
	chase_da_CreateSegments(cardNum, 1, 2, segs);
	
	printf("Set a marker at the start\n");
	chase_da_SetMarkers(cardNum, 64, 0xF, 0xF);

	chase_da_SetTriggerMode(cardNum, CHASE_DA_MODE_RUN, CHASE_DA_TRIG_POS);

	pause();
	
	return 0;
}
